#!/usr/bin/env python3

#══════════════════════════════════════════════════════════════════════════════════════════════════════════════════
# Class:   Funcs
#──────────────────────────
# Author:  Hengyue Li
#──────────────────────────
# Version: 2019/03/01
#──────────────────────────
# discription:
#          operation between local PC with a remote server
#          remember to call connect or disconnect for some function.
#
#──────────────────────────
# Imported :
import os , configparser 
#──────────────────────────
# Interface:
#
#        [fun] readConfig(path)
#              return a dict used for paramiko  
# 
#        [sub] mkConfig(path)
#              create a new configuration file.    
#══════════════════════════════════════════════════════════════════════════════════════════════════════════════════

class Funcs():
    
    @staticmethod
    def readConfig(path): 
        if os.path.isfile(path):
            config = configparser.ConfigParser()
            config.read(path)  
            paramikoCon = dict(config._sections['Server configuration'])
            return paramikoCon
        else:
            return "error: configurate file: {} not exist".format(path)
            
    
    @staticmethod
    def mkConfig(path):
        S = """[Server configuration]
# If password is empty, this must be specified.
hostname = 1.1.1.1   
username = root      
#port =  22         
#password  =  FLVFjn17cxpdGEWQ2S      
#key_filename = local/path/to/key.pem 
        """
        open(path,'w').write(S)




import setuptools
#from setuptools import setup

setuptools.setup(
    name='easycon',
    scripts=['easycon', 'easycon.cmd'] ,
    version='2019.04.19.0731',
    author='Hengyue Li',
    author_email='hengyue.li@hengyue.li',
    packages=setuptools.find_packages(),
    license='LICENSE.md',
    description='A tool based on paramiko used to connect to remote server.',
    long_description=open('README.md',encoding="utf8").read(),
    long_description_content_type="text/markdown",
    install_requires=['asn1crypto==0.24.0', 'bcrypt==3.1.6', 'cffi==1.12.2', 'colorama==0.4.1', 'cryptography==2.4.2', 'HY-sshapi==2019.4.11.2029', 'idna==2.7', 'paramiko==2.4.2', 'pyasn1==0.4.5', 'pycparser==2.19', 'PyNaCl==1.3.0', 'six==1.12.0', 'termcolor==1.1.0'],
    python_requires='>=3.5',
    url = "https://github.com/HengyueLi/easycon",
)
